@@ -8,12 +8,11 @@ fn submit_order_limit() {
         fee_maker: -0.00025,
         fee_taker: 0.00075,
         starting_balance: 1.0,
-        use_candles: false,
         leverage: 1.0,
         futures_type: FuturesType::Inverse,
     };
     let mut exchange = Exchange::new(config);
-    exchange.update_state(1000.0, 1000.0, 0);
+    exchange.update_state(1000.0, 1000.0, 0, 1000.0, 1000.0);
 
     // submit working market order
     let o = Order::market(Side::Buy, 500.0).unwrap();
@@ -40,18 +39,17 @@ fn handle_stop_market_order_w_trade() {
         fee_maker: -0.00025,
         fee_taker: 0.00075,
         starting_balance: 1.0,
-        use_candles: false,
         leverage: 1.0,
         futures_type: FuturesType::Inverse,
     };
     let mut exchange = Exchange::new(config);
-    exchange.update_state(1000.0, 1000.0, 0);
+    exchange.update_state(1000.0, 1000.0, 0, 1000.0, 1000.0);
 
     let o = Order::stop_market(Side::Buy, 1010.0, 100.0).unwrap();
     exchange.submit_order(o).unwrap();
     assert_eq!(exchange.account().active_stop_orders().len(), 1);
 
-    exchange.update_state(1010.0, 1010.0, 1);
+    exchange.update_state(1010.0, 1010.0, 1, 1010.0, 1010.0);
 
     assert_eq!(exchange.account().position().size(), 100.0);
     assert_eq!(exchange.account().position().entry_price(), 1010.0);
@@ -63,13 +61,12 @@ fn inv_long_market_win_full() {
         fee_maker: -0.00025,
         fee_taker: 0.00075,
         starting_balance: 1.0,
-        use_candles: false,
         leverage: 1.0,
         futures_type: FuturesType::Inverse,
     };
     let fee_taker = config.fee_taker;
     let mut exchange = Exchange::new(config);
-    exchange.update_state(1000.0, 1000.0, 0);
+    exchange.update_state(1000.0, 1000.0, 0, 1000.0, 1000.0);
 
     let value = exchange.account().margin().available_balance() * 0.8;
     let size = exchange.ask() * value;
@@ -77,7 +74,7 @@ fn inv_long_market_win_full() {
     let order_err = exchange.submit_order(o);
     assert!(order_err.is_ok());
 
-    exchange.update_state(1000.0, 1000.0, 1);
+    exchange.update_state(1000.0, 1000.0, 1, 1000.0, 1000.0);
 
     let fee_base = size * fee_taker;
     let fee_asset1 = fee_base / exchange.bid();
@@ -95,7 +92,7 @@ fn inv_long_market_win_full() {
         round(0.2 - fee_asset1, 4)
     );
 
-    exchange.update_state(2000.0, 2000.0, 1);
+    exchange.update_state(2000.0, 2000.0, 1, 2000.0, 2000.0);
     assert_eq!(exchange.account().position().unrealized_pnl(), 0.4);
 
     let size = 800.0;
@@ -127,18 +124,17 @@ fn inv_long_market_loss_full() {
         fee_maker: 0.0,
         fee_taker: 0.0,
         starting_balance: 1.0,
-        use_candles: false,
         leverage: 1.0,
         futures_type: FuturesType::Inverse,
     };
     let fee_taker = config.fee_taker;
     let mut exchange = Exchange::new(config);
-    exchange.update_state(1000.0, 1000.0, 0);
+    exchange.update_state(1000.0, 1000.0, 0, 1000.0, 1000.0);
 
     let o = Order::market(Side::Buy, 800.0).unwrap();
     let order_err = exchange.submit_order(o);
     assert!(order_err.is_ok());
-    exchange.update_state(1000.0, 1000.0, 1);
+    exchange.update_state(1000.0, 1000.0, 1, 1000.0, 1000.0);
 
     assert_eq!(exchange.account().position().size(), 800.0);
     assert_eq!(exchange.account().position().entry_price(), 1000.0);
@@ -151,12 +147,12 @@ fn inv_long_market_loss_full() {
     assert_eq!(exchange.account().margin().order_margin(), 0.0);
     assert_eq!(exchange.account().margin().position_margin(), 0.8);
 
-    exchange.update_state(800.0, 800.0, 2);
+    exchange.update_state(800.0, 800.0, 2, 800.0, 800.0);
     assert_eq!(exchange.account().position().unrealized_pnl(), -0.2);
 
     let o = Order::market(Side::Sell, 800.0).unwrap();
     exchange.submit_order(o).unwrap();
-    exchange.update_state(800.0, 800.0, 3);
+    exchange.update_state(800.0, 800.0, 3, 800.0, 800.0);
 
     let fee_base0 = fee_taker * 800.0;
     let fee_asset0 = fee_base0 / 1000.0;
@@ -185,28 +181,27 @@ fn inv_short_market_win_full() {
         fee_maker: -0.00025,
         fee_taker: 0.00075,
         starting_balance: 1.0,
-        use_candles: false,
         leverage: 1.0,
         futures_type: FuturesType::Inverse,
     };
     let fee_taker = config.fee_taker;
     let mut exchange = Exchange::new(config);
-    exchange.update_state(1000.0, 1000.0, 0);
+    exchange.update_state(1000.0, 1000.0, 0, 1000.0, 1000.0);
 
     let o = Order::market(Side::Sell, 800.0).unwrap();
     let order_err = exchange.submit_order(o);
     assert!(order_err.is_ok());
-    exchange.update_state(1000.0, 1000.0, 1);
+    exchange.update_state(1000.0, 1000.0, 1, 1000.0, 1000.0);
 
     assert_eq!(exchange.account().position().size(), -800.0);
 
-    exchange.update_state(800.0, 800.0, 1);
+    exchange.update_state(800.0, 800.0, 1, 800.0, 800.0);
     assert_eq!(exchange.account().position().unrealized_pnl(), 0.2);
 
     let o = Order::market(Side::Buy, 800.0).unwrap();
     let order_err = exchange.submit_order(o);
     assert!(order_err.is_ok());
-    exchange.update_state(800.0, 800.0, 2);
+    exchange.update_state(800.0, 800.0, 2, 800.0, 800.0);
 
     let fee_base0 = fee_taker * 800.0;
     let fee_asset0 = fee_base0 / 1000.0;
@@ -235,13 +230,12 @@ fn inv_short_market_loss_full() {
         fee_maker: -0.00025,
         fee_taker: 0.00075,
         starting_balance: 1.0,
-        use_candles: false,
         leverage: 1.0,
         futures_type: FuturesType::Inverse,
     };
     let fee_taker = config.fee_taker;
     let mut exchange = Exchange::new(config);
-    exchange.update_state(1000.0, 1000.0, 0);
+    exchange.update_state(1000.0, 1000.0, 0, 1000.0, 1000.0);
 
     let value = exchange.account().margin().available_balance() * 0.4;
     let size = exchange.ask() * value;
@@ -249,7 +243,7 @@ fn inv_short_market_loss_full() {
     let order_err = exchange.submit_order(o);
     assert!(order_err.is_ok());
 
-    exchange.update_state(1000.0, 1000.0, 1);
+    exchange.update_state(1000.0, 1000.0, 1, 1000.0, 1000.0);
 
     let fee_base1 = size * fee_taker;
     let fee_asset1 = fee_base1 / exchange.bid();
@@ -267,7 +261,7 @@ fn inv_short_market_loss_full() {
         0.6 - fee_asset1
     );
 
-    exchange.update_state(2000.0, 2000.0, 2);
+    exchange.update_state(2000.0, 2000.0, 2, 2000.0, 2000.0);
 
     let size = 400.0;
     let fee_base2 = size * fee_taker;
@@ -279,7 +273,7 @@ fn inv_short_market_loss_full() {
     let order_err = exchange.submit_order(o);
     assert!(order_err.is_ok());
 
-    exchange.update_state(2000.0, 2000.0, 3);
+    exchange.update_state(2000.0, 2000.0, 3, 2000.0, 2000.0);
 
     assert_eq!(exchange.account().position().size(), 0.0);
     assert_eq!(exchange.account().position().unrealized_pnl(), 0.0);
@@ -300,13 +294,12 @@ fn inv_long_market_win_partial() {
         fee_maker: -0.00025,
         fee_taker: 0.00075,
         starting_balance: 1.0,
-        use_candles: false,
         leverage: 1.0,
         futures_type: FuturesType::Inverse,
     };
     let fee_taker = config.fee_taker;
     let mut exchange = Exchange::new(config);
-    exchange.update_state(1000.0, 1000.0, 0);
+    exchange.update_state(1000.0, 1000.0, 0, 1000.0, 1000.0);
 
     let value = exchange.account().margin().available_balance() * 0.8;
     let size = exchange.ask() * value;
@@ -314,7 +307,7 @@ fn inv_long_market_win_partial() {
     let order_err = exchange.submit_order(o);
     assert!(order_err.is_ok());
 
-    exchange.update_state(1000.0, 1000.0, 1);
+    exchange.update_state(1000.0, 1000.0, 1, 1000.0, 1000.0);
 
     let fee_base = size * fee_taker;
     let fee_asset1 = fee_base / exchange.bid();
@@ -332,7 +325,7 @@ fn inv_long_market_win_partial() {
         round(0.2 - fee_asset1, 4)
     );
 
-    exchange.update_state(2000.0, 2000.0, 1);
+    exchange.update_state(2000.0, 2000.0, 1, 2000.0, 2000.0);
 
     let size = 400.0;
     let fee_base2 = size * fee_taker;
@@ -344,7 +337,7 @@ fn inv_long_market_win_partial() {
     let order_err = exchange.submit_order(o);
     assert!(order_err.is_ok());
 
-    exchange.update_state(2000.0, 2000.0, 2);
+    exchange.update_state(2000.0, 2000.0, 2, 2000.0, 2000.0);
 
     assert_eq!(exchange.account().position().size(), 400.0);
     assert_eq!(exchange.account().position().entry_price(), 1000.0);
@@ -366,28 +359,27 @@ fn inv_long_market_loss_partial() {
         fee_maker: -0.00025,
         fee_taker: 0.00075,
         starting_balance: 1.0,
-        use_candles: false,
         leverage: 1.0,
         futures_type: FuturesType::Inverse,
     };
     let fee_taker = config.fee_taker;
     let mut exchange = Exchange::new(config);
-    exchange.update_state(1000.0, 1000.0, 0);
+    exchange.update_state(1000.0, 1000.0, 0, 1000.0, 1000.0);
 
     let o = Order::market(Side::Buy, 800.0).unwrap();
     let order_err = exchange.submit_order(o);
     assert!(order_err.is_ok());
-    exchange.update_state(1000.0, 1000.0, 1);
+    exchange.update_state(1000.0, 1000.0, 1, 1000.0, 1000.0);
 
     assert_eq!(exchange.account().position().size(), 800.0);
 
-    exchange.update_state(800.0, 800.0, 1);
+    exchange.update_state(800.0, 800.0, 1, 800.0, 800.0);
     assert_eq!(exchange.account().position().unrealized_pnl(), -0.2);
 
     let o = Order::market(Side::Sell, 400.0).unwrap();
     let order_err = exchange.submit_order(o);
     assert!(order_err.is_ok());
-    exchange.update_state(800.0, 800.0, 1);
+    exchange.update_state(800.0, 800.0, 1, 800.0, 800.0);
 
     let fee_base0 = fee_taker * 800.0;
     let fee_asset0 = fee_base0 / 1000.0;
@@ -416,18 +408,17 @@ fn inv_short_market_win_partial() {
         fee_maker: 0.0,
         fee_taker: 0.00075,
         starting_balance: 1.0,
-        use_candles: false,
         leverage: 1.0,
         futures_type: FuturesType::Inverse,
     };
     let fee_taker = config.fee_taker;
     let mut exchange = Exchange::new(config);
-    exchange.update_state(1000.0, 1000.0, 0);
+    exchange.update_state(1000.0, 1000.0, 0, 1000.0, 1000.0);
 
     let o = Order::market(Side::Sell, 800.0).unwrap();
     let order_err = exchange.submit_order(o);
     assert!(order_err.is_ok());
-    exchange.update_state(1000.0, 1000.0, 1);
+    exchange.update_state(1000.0, 1000.0, 1, 1000.0, 1000.0);
 
     assert_eq!(exchange.account().position().size(), -800.0);
     assert_eq!(exchange.account().position().entry_price(), 1000.0);
@@ -440,14 +431,14 @@ fn inv_short_market_win_partial() {
     assert_eq!(exchange.account().margin().order_margin(), 0.0);
     assert_eq!(exchange.account().margin().position_margin(), 0.8);
 
-    exchange.update_state(800.0, 800.0, 2);
+    exchange.update_state(800.0, 800.0, 2, 800.0, 800.0);
 
     assert_eq!(exchange.account().position().unrealized_pnl(), 0.2);
 
     let o = Order::market(Side::Buy, 400.0).unwrap();
     let order_err = exchange.submit_order(o);
     assert!(order_err.is_ok());
-    exchange.update_state(800.0, 800.0, 3);
+    exchange.update_state(800.0, 800.0, 3, 800.0, 800.0);
 
     let fee_base0 = fee_taker * 800.0;
     let fee_asset0 = fee_base0 / 1000.0;
@@ -476,13 +467,12 @@ fn inv_short_market_loss_partial() {
         fee_maker: -0.00025,
         fee_taker: 0.00075,
         starting_balance: 1.0,
-        use_candles: false,
         leverage: 1.0,
         futures_type: FuturesType::Inverse,
     };
     let fee_taker = config.fee_taker;
     let mut exchange = Exchange::new(config);
-    exchange.update_state(1000.0, 1000.0, 0);
+    exchange.update_state(1000.0, 1000.0, 0, 1000.0, 1000.0);
 
     let value = exchange.account().margin().available_balance() * 0.8;
     let size = exchange.ask() * value;
@@ -490,7 +480,7 @@ fn inv_short_market_loss_partial() {
     let order_err = exchange.submit_order(o);
     assert!(order_err.is_ok());
 
-    exchange.update_state(1000.0, 1000.0, 1);
+    exchange.update_state(1000.0, 1000.0, 1, 1000.0, 1000.0);
 
     let fee_base1 = size * fee_taker;
     let fee_asset1 = fee_base1 / exchange.bid();
@@ -507,7 +497,7 @@ fn inv_short_market_loss_partial() {
         round(exchange.account().margin().available_balance(), 4),
         round(0.2 - fee_asset1, 4)
     );
-    exchange.update_state(2000.0, 2000.0, 1);
+    exchange.update_state(2000.0, 2000.0, 1, 2000.0, 2000.0);
 
     let size = 400.0;
     let fee_base2 = size * fee_taker;
@@ -538,20 +528,19 @@ fn inv_test_market_roundtrip() {
         fee_maker: -0.00025,
         fee_taker: 0.00075,
         starting_balance: 1.0,
-        use_candles: false,
         leverage: 1.0,
         futures_type: FuturesType::Inverse,
     };
     let fee_taker = config.fee_taker;
     let mut exchange = Exchange::new(config);
-    exchange.update_state(1000.0, 1000.0, 0);
+    exchange.update_state(1000.0, 1000.0, 0, 1000.0, 1000.0);
 
     let value = exchange.account().margin().available_balance() * 0.9;
     let size = exchange.ask() * value;
     let buy_order = Order::market(Side::Buy, size).unwrap();
     let order_err = exchange.submit_order(buy_order);
     assert!(order_err.is_ok());
-    exchange.update_state(1000.0, 1000.0, 1);
+    exchange.update_state(1000.0, 1000.0, 1, 1000.0, 1000.0);
 
     let sell_order = Order::market(Side::Sell, size).unwrap();
 
@@ -561,7 +550,7 @@ fn inv_test_market_roundtrip() {
     let fee_base = size * fee_taker;
     let fee_asset = fee_base / exchange.ask();
 
-    exchange.update_state(1000.0, 1000.0, 2);
+    exchange.update_state(1000.0, 1000.0, 2, 1000.0, 1000.0);
 
     assert_eq!(exchange.account().position().size(), 0.0);
     assert_eq!(exchange.account().position().entry_price(), 1000.0);
@@ -580,7 +569,7 @@ fn inv_test_market_roundtrip() {
     let buy_order = Order::market(Side::Buy, size).unwrap();
     let order_err = exchange.submit_order(buy_order);
     assert!(order_err.is_ok());
-    exchange.update_state(1000.0, 1000.0, 3);
+    exchange.update_state(1000.0, 1000.0, 3, 1000.0, 1000.0);
 
     let size = 950.0;
     let sell_order = Order::market(Side::Sell, size).unwrap();
@@ -588,7 +577,7 @@ fn inv_test_market_roundtrip() {
     let order_err = exchange.submit_order(sell_order);
     assert!(order_err.is_ok());
 
-    exchange.update_state(1000.0, 1000.0, 4);
+    exchange.update_state(1000.0, 1000.0, 4, 1000.0, 1000.0);
 
     assert_eq!(exchange.account().position().size(), -50.0);
     assert_eq!(exchange.account().position().entry_price(), 1000.0);
@@ -614,12 +603,11 @@ fn inv_execute_limit() {
         fee_maker: 0.0,
         fee_taker: 0.001,
         starting_balance: 1.0,
-        use_candles: false,
         leverage: 1.0,
         futures_type: FuturesType::Inverse,
     };
     let mut exchange = Exchange::new(config.clone());
-    exchange.update_state(1000.0, 1000.0, 0);
+    exchange.update_state(1000.0, 1000.0, 0, 1000.0, 1000.0);
 
     let o: Order = Order::limit(Side::Buy, 900.0, 450.0).unwrap();
     exchange.submit_order(o).unwrap();
@@ -627,7 +615,7 @@ fn inv_execute_limit() {
     assert_eq!(exchange.account().margin().available_balance(), 0.5);
     assert_eq!(exchange.account().margin().order_margin(), 0.5);
 
-    let (exec_orders, liq) = exchange.update_state(750.0, 750.0, 1);
+    let (exec_orders, liq) = exchange.update_state(750.0, 750.0, 1, 750.0, 750.0);
     assert!(!liq);
     assert_eq!(exec_orders.len(), 1);
 
@@ -643,7 +631,7 @@ fn inv_execute_limit() {
     assert!(order_err.is_ok());
     assert_eq!(exchange.account().active_limit_orders().len(), 1);
 
-    exchange.update_state(1200.0, 1200.0, 1);
+    exchange.update_state(1200.0, 1200.0, 1, 1200.0, 1200.0);
 
     assert_eq!(exchange.account().active_limit_orders().len(), 0);
     assert_eq!(exchange.account().position().size(), 0.0);
@@ -655,7 +643,7 @@ fn inv_execute_limit() {
     exchange.submit_order(o).unwrap();
     assert_eq!(exchange.account().active_limit_orders().len(), 1);
 
-    exchange.update_state(1200.0, 1201.0, 2);
+    exchange.update_state(1200.0, 1201.0, 2, 1201.0, 1200.0);
     assert_eq!(exchange.account().position().size(), -600.0);
     assert_eq!(round(exchange.account().margin().position_margin(), 1), 0.5);
     assert_eq!(round(exchange.account().margin().wallet_balance(), 2), 1.05);
